Objetto Qt
==========
.. image:: https://github.com/brunonicko/objettoqt/workflows/Lint/badge.svg
   :target: https://github.com/brunonicko/objettoqt/actions?query=workflow%3ALint

.. image:: https://github.com/brunonicko/objettoqt/workflows/Tests/badge.svg
   :target: https://github.com/brunonicko/objettoqt/actions?query=workflow%3ATests

.. image:: https://readthedocs.org/projects/objettoqt/badge/?version=stable
   :target: https://objettoqt.readthedocs.io/en/stable/

.. image:: https://img.shields.io/github/license/brunonicko/objettoqt?color=light-green
   :target: https://github.com/brunonicko/objettoqt/blob/master/LICENSE

.. image:: https://static.pepy.tech/personalized-badge/objettoqt?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads
   :target: https://pepy.tech/project/objettoqt

.. image:: https://img.shields.io/pypi/pyversions/objettoqt?color=light-green&style=flat
   :target: https://pypi.org/project/objettoqt/

.. image:: https://badge.fury.io/py/objettoqt.svg
   :target: https://pypi.org/project/objettoqt/


Utilities to use `Objetto <https://github.com/brunonicko/objetto>`_ with
`Qt <https://github.com/mottosso/Qt.py>`_.

.. note::
   This package is not ready for production use yet.
